==> fs_moodle5-00-00_1-8-14_20120412.zip: moodle/blog/edit.php <==
<?php //$Id: edit.php,v 1.43.2.3 2010/03/07 15:15:59 skodak Exp $

require_once('../config.php');
include_once('lib.php');

$action   = required_param('action', PARAM_ALPHA);
$id       = optional_param('id', 0, PARAM_INT);
// (Shirai163): ブログに返信機能を追加 (2009/08/26)
// (Shirai163): ここから追加
$replyid  = optional_param('replyid', 0, PARAM_INT);
// (Shirai163): ここまで追加
$confirm  = optional_param('confirm', 0, PARAM_BOOL);
$courseid = optional_param('courseid', 0, PARAM_INT); // needed for user tab - does nothing here

require_login($courseid);

if (empty($CFG->bloglevel)) {
    error('Blogging is disabled!');
}

if (isguest()) {
    error(get_string('noguestpost', 'blog'));
}

$sitecontext = get_context_instance(CONTEXT_SYSTEM, SITEID);
if (!has_capability('moodle/blog:create', $sitecontext) and !has_capability('moodle/blog:manageentries', $sitecontext)) {
    error('You can not post or edit blogs.');
}

// Make sure that the person trying to edit have access right
if ($id) {
    if (!$existing = get_record('post', 'id', $id)) {
        error('Wrong blog post id');
    }

    if (!blog_user_can_edit_post($existing)) {
        error(get_string('notallowedtoedit', 'blog'));
    }
    $userid    = $existing->userid;
    $returnurl = $CFG->wwwroot.'/blog/index.php?userid='.$existing->userid;
} else {
    if (!has_capability('moodle/blog:create', $sitecontext)) {
        error(get_string('nopost', 'blog')); // manageentries is not enough for adding
    }
    $existing  = false;
    $userid    = $USER->id;
    $returnurl = 'index.php?userid='.$USER->id;
}
if (!empty($courseid)) {
    $returnurl .= '&amp;courseid='.$courseid;
}


$strblogs = get_string('blogs','blog');

if ($action=='delete'){
    if (!$existing) {
        error('Incorrect blog post id');
    }
    if (data_submitted() and $confirm and confirm_sesskey()) {
        do_delete($existing);
        redirect($returnurl);
    } else {
        $optionsyes = array('id'=>$id, 'action'=>'delete', 'confirm'=>1, 'sesskey'=>sesskey(), 'courseid'=>$courseid);
        $optionsno = array('userid'=>$existing->userid, 'courseid'=>$courseid);
        print_header("$SITE->shortname: $strblogs", $SITE->fullname);
        blog_print_entry($existing);
        echo '<br />';
        notice_yesno(get_string('blogdeleteconfirm', 'blog'), 'edit.php', 'index.php', $optionsyes, $optionsno, 'post', 'get');
// (Debug024): ここから修正
//      print_footer();
        print_footer($COURSE);
// (Debug024): ここまで修正
        die;
    }
}

require_once('edit_form.php');
$blogeditform = new blog_edit_form(null, compact('existing', 'sitecontext'));

if ($blogeditform->is_cancelled()){
    redirect($returnurl);
} else if ($blogeditform->no_submit_button_pressed()) {
    no_submit_button_actions($blogeditform, $sitecontext);


} else if ($fromform = $blogeditform->get_data()){
    //save stuff in db
    switch ($action) {
// (Shirai163): ここから追加
        case 'reply':
// (Shirai163): ここまで追加
        case 'add':
            do_add($fromform, $blogeditform);
        break;

        case 'edit':
            if (!$existing) {
                error('Incorrect blog post id');
            }
            do_edit($fromform, $blogeditform);
        break;
        default :
            error('Unknown action!');
    }
    redirect($returnurl);
}


// gui setup
switch ($action) {
// (Shirai163): ここから追加
    case 'reply':
// (Shirai163): ここまで追加
    case 'add':
        // prepare new empty form
        $post->publishstate = 'draft';
        $strformheading = get_string('addnewentry', 'blog');
        $post->action       = $action;
// (Shirai163): ここから追加
        if ($action == 'reply') {
            if (empty($replyid) || !$replyexisting = get_record('post', 'id', $replyid)) {
                error('Wrong blog post id');
            }
            $post->subject = 'Re: '.$replyexisting->subject;
            $post->summary = get_string('replytothisblogentry', 'fs_moodle').'&nbsp;:&nbsp;'.link2blogEntry($replyid, !fs_function_enable('FS_DISABLE_FORUM_EXSEARCH'));
            $post->summary .= '<br /><br />';
            $post->summary = format_text($post->summary);

            // tagをコピー
            if ($ptags = get_records_sql_menu("SELECT t.id, t.text FROM
                                         {$CFG->prefix}tags t,
                                         {$CFG->prefix}blog_tag_instance bti
                                         WHERE t.id = bti.tagid
                                         AND t.type = 'personal'
                                         AND bti.entryid = {$replyid}")) {

                $post->ptags = implode(', ', $ptags);
            } else {
                //$idsql = " AND bti.entryid = 0";
                //was used but seems redundant.
                $post->ptags = '';
            }
            if ($otags = get_records_sql_menu("SELECT t.id, t.text FROM
                                         {$CFG->prefix}tags t,
                                         {$CFG->prefix}blog_tag_instance bti
                                         WHERE t.id = bti.tagid
                                         AND t.type = 'official'
                                         AND bti.entryid = {$replyid}")){
                $post->otags = array_keys($otags);
            }
        }
// (Shirai163): ここまで追加
    break;

    case 'edit':
        if (!$existing) {
            error('Incorrect blog post id');
        }
        $post->id           = $existing->id;
        $post->subject      = clean_text($existing->subject);
        $post->summary      = clean_text($existing->summary, $existing->format);
        $post->publishstate = $existing->publishstate;
        $post->format       = $existing->format;
        $post->action       = $action;
        $strformheading = get_string('updateentrywithid', 'blog');

        if ($ptags = get_records_sql_menu("SELECT t.id, t.text FROM
                                     {$CFG->prefix}tags t,
                                     {$CFG->prefix}blog_tag_instance bti
                                     WHERE t.id = bti.tagid
                                     AND t.type = 'personal'
                                     AND bti.entryid = {$post->id}")) {

            $post->ptags = implode(', ', $ptags);
        } else {
            //$idsql = " AND bti.entryid = 0";
            //was used but seems redundant.
            $post->ptags = '';
        }
        if ($otags = get_records_sql_menu("SELECT t.id, t.text FROM
                                     {$CFG->prefix}tags t,
                                     {$CFG->prefix}blog_tag_instance bti
                                     WHERE t.id = bti.tagid
                                     AND t.type = 'official'
                                     AND bti.entryid = {$post->id}")){
            $post->otags = array_keys($otags);
        }
    break;
    default :
        error('Unknown action!');
}

// done here in order to allow deleting of posts with wrong user id above
if (!$user = get_record('user', 'id', $userid)) {
    error('Incorrect user id');
}

print_header("$SITE->shortname: $strblogs", $SITE->fullname,
                '<a href="'.$CFG->wwwroot.'/user/view.php?id='.$userid.'">'.fullname($user).'</a> ->
                <a href="'.$CFG->wwwroot.'/blog/index.php?userid='.$userid.'">'.$strblogs.'</a> -> '.$strformheading,'','',true);
// (Shirai163): ここから追加
if ($action == 'reply') {
    blog_print_html_formatted_entries($replyid, $post->publishstate, $USER->id, 0, '');
}
// (Shirai163): ここまで追加
$blogeditform->set_data($post);
$blogeditform->display();


print_footer();


die;

/*****************************   edit.php functions  ***************************/
function no_submit_button_actions(&$blogeditform, $sitecontext){
    $mform =& $blogeditform->_form;
    $data = $mform->exportValues();
    //sesskey has been checked already no need to check that
    //check for official tags to add
    if (!empty($data['addotags']) && !empty($data['otagsadd'])){ // adding official tag
        $error = add_otag($data['otagsadd']);
    }
    if (!empty($error)){
        $mform->setElementError('otagsgrp', $error);
    }
    if (!empty($data['deleteotags']) && !empty($data['otags'])){ // adding official tag
        delete_otags($data['otags'], $sitecontext);
    }
    $blogeditform->otags_select_setup();
}

function delete_otags($tagids, $sitecontext){
    foreach ($tagids as $tagid) {

        if (!$tag = get_record('tags', 'id', $tagid)) {
            error('Can not delete tag, tag doesn\'t exist');
        }

        if ($tag->type == 'official' and !has_capability('moodle/blog:manageofficialtags', $sitecontext)) {
            //can not delete
            error('Can not delete tag, you don\'t have permission to delete an official tag');
        }

        if ($tag->type == 'personal' and !has_capability('moodle/blog:managepersonaltags', $sitecontext)) {
            //can not delete
            error('Can not delete tag, you don\'t have permission to delete a personal tag');
        }

        // Delete the tag itself
        if (!delete_records('tags', 'id', $tagid)) {
            error('Can not delete tag');
        }

        // Deleteing all references to this tag
        if (!delete_records('blog_tag_instance', 'tagid', $tagid)) {
            error('Can not delete blog tag instances');
        }


    }
}

function add_otag($otag){
    global $USER;
    $error = '';
    if ($tag = get_record('tags', 'text', $otag)) {
        if ($tag->type == 'official') {
            // official tag already exist
            $error = get_string('tagalready');
        } else {
            $tag->type = 'official';
            update_record('tags', $tag);
            $tagid = $tag->id;
        }
    } else { // Brand new offical tag

        $tag = new object();
        $tag->userid = $USER->id;
        $tag->text   = $otag;
        $tag->type   = 'official';

        if (!$tagid = insert_record('tags', $tag)) {
            error('Can not create tag!');
        }
    }
    return $error;
}

/*
* Delete blog post from database
*/
function do_delete($post) {
    global $returnurl;

    $status = delete_records('post', 'id', $post->id);
    $status = delete_records('blog_tag_instance', 'entryid', $post->id) and $status;
    
    blog_delete_old_attachments($post);
    
    add_to_log(SITEID, 'blog', 'delete', 'index.php?userid='. $post->userid, 'deleted blog entry with entry id# '. $post->id);

    if (!$status) {
        error('Error occured while deleting post', $returnurl);
    }
}

/**
 * Write a new blog entry into database
 */
function do_add($post, $blogeditform) {
    global $CFG, $USER, $returnurl;

    $post->module       = 'blog';
    $post->userid       = $USER->id;
    $post->lastmodified = time();
    $post->created      = time();

    // Insert the new blog entry.
    if ($id = insert_record('post', $post)) {
        $post->id = $id;
        // add blog attachment
        $dir = blog_file_area_name($post);
        if ($blogeditform->save_files($dir) and $newfilename = $blogeditform->get_new_filename()) {
            set_field("post", "attachment", $newfilename, "id", $post->id);
        }
        add_tags_info($post->id);
        add_to_log(SITEID, 'blog', 'add', 'index.php?userid='.$post->userid.'&postid='.$post->id, $post->subject);

    } else {
        error('There was an error adding this post in the database', $returnurl);
    }

}

/**
 * @param . $post argument is a reference to the post object which is used to store information for the form
 * @param . $bloginfo_arg argument is reference to a blogInfo object.
 * @todo complete documenting this function. enable trackback and pingback between entries on the same server
 */
function do_edit($post, $blogeditform) {

    global $CFG, $USER, $returnurl;


    $post->lastmodified = time();

    $dir = blog_file_area_name($post);
    if ($blogeditform->save_files($dir) and $newfilename = $blogeditform->get_new_filename()) {
        $post->attachment = $newfilename;
    }

    // update record
    if (update_record('post', $post)) {
        // delete all tags associated with this entry
        delete_records('blog_tag_instance', 'entryid', $post->id);
        // add them back
        add_tags_info($post->id);


        add_to_log(SITEID, 'blog', 'update', 'index.php?userid='.$post->userid.'&postid='.$post->id, $post->subject);

    } else {
        error('There was an error updating this post in the database', $returnurl);
    }
}

/**
 * function to attach tags into a post
 * @param int postid - id of the blog
 */
function add_tags_info($postid) {

    global $USER;

    $post = get_record('post', 'id', $postid);

    $tag = new object();
    $tag->entryid = $post->id;
    $tag->userid = $post->userid;
    $tag->timemodified = time();

    /// Attach official tags
    if ($otags = optional_param('otags', '', PARAM_INT)) {
        foreach ($otags as $otag) {
            $tag->tagid = $otag;
            insert_record('blog_tag_instance', $tag);
        }
    }

    /// Attach Personal Tags
    if ($ptags = optional_param('ptags', '', PARAM_NOTAGS)) {
        $ptags = explode(',', $ptags);
        foreach ($ptags as $ptag) {
            $ptag = trim($ptag);
            // check for existance
            // it does not matter whether it is an offical tag or personal tag
            // we do not want to have 1 copy of offical tag and 1 copy of personal tag (for the same tag)
            if ($ctag = get_record('tags', 'text', $ptag)) {
                $tag->tagid = $ctag->id;
                insert_record('blog_tag_instance', $tag);
            } else { // create a personal tag
                $ctag = new object;
                $ctag->userid = $USER->id;
                $ctag->text = $ptag;
                $ctag->type = 'personal';
                if ($tagid = insert_record('tags', $ctag)) {
                    $tag->tagid = $tagid;
                    insert_record('blog_tag_instance', $tag);
                }
            }
        }
    }
}
?>

==> fs_moodle5-00-01_1-9-19_20120721.zip: moodle/blog/edit.php <==
<?php //$Id: edit.php,v 1.49.2.13 2010/03/07 15:16:19 skodak Exp $

require_once('../config.php');
include_once('lib.php');
include_once($CFG->dirroot.'/tag/lib.php');

$action   = required_param('action', PARAM_ALPHA);
$id       = optional_param('id', 0, PARAM_INT);
// (Shirai163): ブログに返信機能を追加 (2009/08/26)
// (Shirai163): ここから追加
$replyid  = optional_param('replyid', 0, PARAM_INT);
// (Shirai163): ここまで追加
$confirm  = optional_param('confirm', 0, PARAM_BOOL);
$courseid = optional_param('courseid', 0, PARAM_INT); // needed for user tab - does nothing here
// (Debug024): blogの編集時にコースIDを渡していない箇所の修正 (2009/07/21)
// (Debug024): ここから追加
    course_setup($courseid);
// (Debug024): ここまで追加

require_login($courseid);

if (empty($CFG->bloglevel)) {
    error('Blogging is disabled!');
}

if (isguest()) {
    print_error('noguestpost', 'blog');
}

$sitecontext = get_context_instance(CONTEXT_SYSTEM);
if (!has_capability('moodle/blog:create', $sitecontext) and !has_capability('moodle/blog:manageentries', $sitecontext)) {
    error('You can not post or edit blogs.');
}

// Make sure that the person trying to edit have access right
if ($id) {
    if (!$existing = get_record('post', 'id', $id)) {
        error('Wrong blog post id');
    }

    if (!blog_user_can_edit_post($existing)) {
        print_error('notallowedtoedit', 'blog');
    }
    $userid    = $existing->userid;
    $returnurl = $CFG->wwwroot.'/blog/index.php?userid='.$existing->userid;
} else {
    if (!has_capability('moodle/blog:create', $sitecontext)) {
        print_error('nopost', 'blog'); // manageentries is not enough for adding
    }
    $existing  = false;
    $userid    = $USER->id;
    $returnurl = 'index.php?userid='.$USER->id;
}
if (!empty($courseid)) {
    $returnurl .= '&amp;courseid='.$courseid;
}


$strblogs = get_string('blogs','blog');

if ($action=='delete'){
    if (!$existing) {
        error('Incorrect blog post id');
    }
    if (data_submitted() and $confirm and confirm_sesskey()) {
        do_delete($existing);
        redirect($returnurl);
    } else {
        $optionsyes = array('id'=>$id, 'action'=>'delete', 'confirm'=>1, 'sesskey'=>sesskey(), 'courseid'=>$courseid);
        $optionsno = array('userid'=>$existing->userid, 'courseid'=>$courseid);
        print_header("$SITE->shortname: $strblogs", $SITE->fullname);
        blog_print_entry($existing);
        echo '<br />';
        notice_yesno(get_string('blogdeleteconfirm', 'blog'), 'edit.php', 'index.php', $optionsyes, $optionsno, 'post', 'get');
// (Debug024): ここから修正
//      print_footer();
        print_footer($COURSE);
// (Debug024): ここまで修正
        die;
    }
}

require_once('edit_form.php');
$blogeditform = new blog_edit_form(null, compact('existing', 'sitecontext'));

if ($blogeditform->is_cancelled()){
    redirect($returnurl);
} else if ($fromform = $blogeditform->get_data()){
    //save stuff in db
    switch ($action) {
// (Shirai163): ここから追加
        case 'reply':
// (Shirai163): ここまで追加
        case 'add':
            do_add($fromform, $blogeditform);
        break;

        case 'edit':
            if (!$existing) {
                error('Incorrect blog post id');
            }
            do_edit($fromform, $blogeditform);
        break;
        default :
            error('Unknown action!');
    }
    redirect($returnurl);
}


// gui setup
switch ($action) {
// (Shirai163): ここから追加
    case 'reply':
// (Shirai163): ここまで追加
    case 'add':
        // prepare new empty form
        $post->publishstate = 'site';
        $strformheading = get_string('addnewentry', 'blog');
        $post->action       = $action;
// (Shirai163): ここから追加
        if ($action == 'reply') {
            if (empty($replyid) || !$replyexisting = get_record('post', 'id', $replyid)) {
                error('Wrong blog post id');
            }
            $post->subject = 'Re: '.$replyexisting->subject;
            $post->summary = get_string('replytothisblogentry', 'fs_moodle').'&nbsp;:&nbsp;'.link2blogEntry($replyid, !fs_function_enable('FS_DISABLE_FORUM_EXSEARCH'));
            $post->summary .= '<br /><br />';
            $post->summary = format_text($post->summary);

            // tagをコピー
            if ($itemptags = tag_get_tags_csv('post', $replyid, TAG_RETURN_TEXT, 'default')) {
                $post->ptags = $itemptags;
            }

            if ($itemotags = tag_get_tags_array('post', $replyid, 'official')) {
                $post->otags = array_keys($itemotags);
            }
        }
// (Shirai163): ここまで追加
    break;

    case 'edit':
        if (!$existing) {
            error('Incorrect blog post id');
        }
        $post->id           = $existing->id;
        $post->subject      = clean_text($existing->subject);
        $post->summary      = clean_text($existing->summary, $existing->format);
        $post->publishstate = $existing->publishstate;
        $post->format       = $existing->format;
        $post->action       = $action;
        $strformheading = get_string('updateentrywithid', 'blog');

        if ($itemptags = tag_get_tags_csv('post', $post->id, TAG_RETURN_TEXT, 'default')) {
            $post->ptags = $itemptags;
        }
        
        if ($itemotags = tag_get_tags_array('post', $post->id, 'official')) {
            $post->otags = array_keys($itemotags);
        }
    break;
    default :
        error('Unknown action!');
}

// done here in order to allow deleting of posts with wrong user id above
if (!$user = get_record('user', 'id', $userid)) {
    error('Incorrect user id');
}
$navlinks = array();
$navlinks[] = array('name' => fullname($user), 'link' => "$CFG->wwwroot/user/view.php?id=$userid", 'type' => 'misc');
$navlinks[] = array('name' => $strblogs, 'link' => "$CFG->wwwroot/blog/index.php?userid=$userid", 'type' => 'misc');
$navlinks[] = array('name' => $strformheading, 'link' => null, 'type' => 'misc');
$navigation = build_navigation($navlinks);

print_header("$SITE->shortname: $strblogs", $SITE->fullname, $navigation,'','',true);
// (Shirai163): ここから追加
if ($action == 'reply') {
    blog_print_html_formatted_entries($replyid, $post->publishstate, $USER->id, 0, '');
}
// (Shirai163): ここまで追加
$blogeditform->set_data($post);
$blogeditform->display();


// (Debug024): ここから修正
// print_footer();
print_footer($COURSE);
// (Debug024): ここまで修正


die;

/*****************************   edit.php functions  ***************************/

/*
* Delete blog post from database
*/
function do_delete($post) {
    global $returnurl;

    $status = delete_records('post', 'id', $post->id);
    //$status = delete_records('blog_tag_instance', 'entryid', $post->id) and $status;
    tag_set('post', $post->id, array());
    
    blog_delete_old_attachments($post);

    add_to_log(SITEID, 'blog', 'delete', 'index.php?userid='. $post->userid, 'deleted blog entry with entry id# '. $post->id);

    if (!$status) {
        error('Error occured while deleting post', $returnurl);
    }
}

/**
 * Write a new blog entry into database
 */
function do_add($post, $blogeditform) {
    global $CFG, $USER, $returnurl;

    $post->module       = 'blog';
    $post->userid       = $USER->id;
    $post->lastmodified = time();
    $post->created      = time();

    // Insert the new blog entry.
    if ($id = insert_record('post', $post)) {
        $post->id = $id;
        // add blog attachment
        $dir = blog_file_area_name($post);
        if ($blogeditform->save_files($dir) and $newfilename = $blogeditform->get_new_filename()) {
            set_field("post", "attachment", $newfilename, "id", $post->id);
        }
        add_tags_info($post->id);
        add_to_log(SITEID, 'blog', 'add', 'index.php?userid='.$post->userid.'&postid='.$post->id, $post->subject);

    } else {
        error('There was an error adding this post in the database', $returnurl);
    }

}

/**
 * @param . $post argument is a reference to the post object which is used to store information for the form
 * @param . $bloginfo_arg argument is reference to a blogInfo object.
 * @todo complete documenting this function. enable trackback and pingback between entries on the same server
 */
function do_edit($post, $blogeditform) {

    global $CFG, $USER, $returnurl;


    $post->lastmodified = time();

    $dir = blog_file_area_name($post);
    if ($blogeditform->save_files($dir) and $newfilename = $blogeditform->get_new_filename()) {
        $post->attachment = $newfilename;
    }

    // update record
    if (update_record('post', $post)) {
        // delete all tags associated with this entry
        
        //delete_records('blog_tag_instance', 'entryid', $post->id);
        //delete_records('tag_instance', 'itemid', $post->id, 'itemtype', 'blog');
        //untag_an_item('post', $post->id);
        // add them back
        add_tags_info($post->id);

        add_to_log(SITEID, 'blog', 'update', 'index.php?userid='.$USER->id.'&postid='.$post->id, $post->subject);

    } else {
        error('There was an error updating this post in the database', $returnurl);
    }
}

/**
 * function to attach tags into a post
 * @param int postid - id of the blog
 */
function add_tags_info($postid) {
    
    $tags = array();
    if ($otags = optional_param('otags', '', PARAM_INT)) {
        foreach ($otags as $tagid) {
            // TODO : make this use the tag name in the form
            if ($tag = tag_get('id', $tagid)) {
                $tags[] = $tag->name;
            }
        }
    }

    $manual_tags = optional_param('ptags', '', PARAM_NOTAGS);
    $tags = array_merge($tags, explode(',', $manual_tags));
    
    tag_set('post', $postid, $tags);
}
?>
